rivet-envoy-protocol 2.3.0-rc.12

Versioned Envoy protocol types for Rivet actor hosts
docs.rs failed to build rivet-envoy-protocol-2.3.0-rc.12
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.